@@ -10,12 +10,14 @@ use namespace::autoclean;
 use Catalyst::Runtime '5.70';
 
 use Catalyst;
+use Test::Catalyst::Log;
 
 __PACKAGE__->config(
     name => 'Test::Serialize',
 );
 
 __PACKAGE__->setup;
+__PACKAGE__->log( Test::Catalyst::Log->new );
 
 1;
 
